@@ -283,35 +283,36 @@ static struct
 {
     gunichar ch;
     gchar   *cbc; 
-    gchar   *military; /* To translators: This is the military phonetic alphabet */
+    gchar   *military;
 }srs_sp_spell_table[] =
     {
-	{'a',	"a",		N_("Alpha")	},
-	{'b',	"b",		N_("Bravo")	},
-	{'c',	"c",		N_("Charlie")	},
-	{'d',	"d",		N_("Delta")	},
-	{'e',	"e",		N_("Echo")	},
-	{'f',	"f",		N_("Foxtrot")	},
-	{'g',	"g",		N_("Golf")	},
-	{'h',	"h",		N_("Hotel")	},
-	{'i',	"i",		N_("India")	},
-	{'j',	"j",		N_("Juliet")	},
-	{'k',	"k",		N_("Kilo")	},
-	{'l',	"l",		N_("Lima")	},
-	{'m',	"m",		N_("Mike")	},
-	{'n',	"n",		N_("November")	},
-	{'o',	"o",		N_("Oscar")	},
-	{'p',	"p",		N_("Papa")	},
-	{'q',	"q",		N_("Quebec")	},
-	{'r',	"r",		N_("Romeo")	},
-	{'s',	"s",		N_("Sierra")	},
-	{'t',	"t",		N_("Tango")	},
-	{'u',	"u",		N_("Uniform")	},
-	{'v',	"v",		N_("Victor")	},
-	{'w',	"w",		N_("Whiskey")	},
-	{'x',	"x",		N_("Xray")	},
-	{'y',	"y",		N_("Yankee")	},
-	{'z',	"z",		N_("Zulu")	},
+	/* To translators: This is the military phonetic alphabet */
+	{'a',	"a",		N_("Phonetic|Alpha")	},
+	{'b',	"b",		N_("Phonetic|Bravo")	},
+	{'c',	"c",		N_("Phonetic|Charlie")	},
+	{'d',	"d",		N_("Phonetic|Delta")	},
+	{'e',	"e",		N_("Phonetic|Echo")	},
+	{'f',	"f",		N_("Phonetic|Foxtrot")	},
+	{'g',	"g",		N_("Phonetic|Golf")	},
+	{'h',	"h",		N_("Phonetic|Hotel")	},
+	{'i',	"i",		N_("Phonetic|India")	},
+	{'j',	"j",		N_("Phonetic|Juliet")	},
+	{'k',	"k",		N_("Phonetic|Kilo")	},
+	{'l',	"l",		N_("Phonetic|Lima")	},
+	{'m',	"m",		N_("Phonetic|Mike")	},
+	{'n',	"n",		N_("Phonetic|November")	},
+	{'o',	"o",		N_("Phonetic|Oscar")	},
+	{'p',	"p",		N_("Phonetic|Papa")	},
+	{'q',	"q",		N_("Phonetic|Quebec")	},
+	{'r',	"r",		N_("Phonetic|Romeo")	},
+	{'s',	"s",		N_("Phonetic|Sierra")	},
+	{'t',	"t",		N_("Phonetic|Tango")	},
+	{'u',	"u",		N_("Phonetic|Uniform")	},
+	{'v',	"v",		N_("Phonetic|Victor")	},
+	{'w',	"w",		N_("Phonetic|Whiskey")	},
+	{'x',	"x",		N_("Phonetic|Xray")	},
+	{'y',	"y",		N_("Phonetic|Yankee")	},
+	{'z',	"z",		N_("Phonetic|Zulu")	},
 	{' ',	N_("space"),	N_("space")	},
 	{'\t',	N_("tab"),	N_("tab")	},
 	{'\n',	N_("new line"),	N_("new line")	},
@@ -373,7 +374,7 @@ srs_speak_text_out (SRSTextOut *tout)
 		g_string_append (text,
 			    tout->spelling == SRS_SPELLING_CHAR ? 
 				    _(srs_sp_spell_table[index].cbc) : 
-				    _(srs_sp_spell_table[index].military));
+				    Q_(srs_sp_spell_table[index].military));
 	    else
 		g_string_append_unichar (text, letter);
 	    srs_gs_speaker_say (voice->speaker, text->str, tout, i);
@@ -543,7 +544,7 @@ srs_sp_clb (gpointer 	   id,
 	    if (srs_crt_out->markers & SRS_MARKER_TEXT_STARTED)
 		srs_sp_callback_wrap (srs_crt_out, tout, SRS_MARKER_TEXT_STARTED,  -1);
 	}
-	if (offset >= 0)
+	if (srs_crt_out->markers & SRS_MARKER_TEXT_PROGRESS && offset >= 0)
 	    srs_sp_callback_wrap (srs_crt_out, tout, SRS_MARKER_TEXT_PROGRESS, offset);
     }
     last = srs_crt_out;
