@@ -39,6 +39,10 @@
 #include "unistd.h"
 #include "src-speech-in.h"
 
+#define SRU_DEBUG_MODULE "srcspeech"
+#define SRU_DEBUG_SCOPES ""
+#include "sru-debug.h"
+
 #define STR(X) (X == NULL? "" : X)
 
 static gboolean src_speech_initialized     = FALSE;
@@ -475,8 +479,8 @@ src_speech_send (gchar *spcoutput)
     else
 	    sru_warning ("speech output: invalid UTF-8 received");
     rv = TRUE;
-    
-/*     fprintf (stderr, "\n%s", spcoutput); */
+
+    sru_debug_log ("out", "send to speech:%s", spcoutput);
 
     busy = FALSE;
 
@@ -1136,6 +1140,14 @@ src_speech_shutup ()
         srcs_out_terminate (last_out);
 	last_out = NULL;
     }
+    if (srcs_outs)
+    {
+	GSList *crt, *tmp = srcs_outs;
+	srcs_outs = NULL;
+	for (crt = tmp; crt; crt = crt->next)
+	    srcs_out_terminate (crt->data);
+	g_slist_free (tmp);
+    }
 
     src_speech_send ("<SRSOUT><SHUTUP/></SRSOUT>");
 }
@@ -1232,12 +1244,12 @@ src_speech_send_chunk (gchar *chunk,
 	srcs_outs = g_slist_remove_link (srcs_outs, tmp);
     }
 										        
-    srcs_outs = g_slist_append (srcs_outs, out);
     if (last_out && srcs_out_can_shutup_out (last_out, out))
     {
 	src_speech_shutup ();
     }
 
+    srcs_outs = g_slist_append (srcs_outs, out);
 #ifdef SRS_NO_MARKERS_SUPPORTED
     if (!src_speech_callback)
 	src_speech_send_from_queue ();
@@ -1511,7 +1523,9 @@ gboolean
 src_speech_init ()
 {
     sru_assert (!src_speech_initialized);
-    
+
+    SRU_DEBUG_ADD_MODULE_AND_SCOPES;
+
     src_speech_idle = TRUE;
     srcs_outs = NULL;
     last_out = NULL;
